@@ -130,11 +130,13 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
         except:
             print 'Trading system file not found. Please input the path to your trading system'
 
+        settings=TSmodule.mySettings()
+
+
     else:
         print "Please input the your trading system's file path or a callable object."
 
     #Import settings from submitted module.
-    settings=TSmodule.mySettings()
 
     #Load market
     if 'OPEN' or 'DATE' or 'HIGH' or 'LOW' or 'CLOSE' or 'VOL' or 'SLIPPAGE' not in globals() or reloadData == True:
@@ -236,7 +238,7 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
            if filePathFlag is True:
                position, settings = TSmodule.myTradingSystem(DATE[t- settings['lookback'] +1:t+1], OPEN[t- settings['lookback'] +1:t+1,:], HIGH[t- settings['lookback'] +1:t+1,:], LOW[t- settings['lookback'] +1:t+1,:], CLOSE[t- settings['lookback']+1:t+1,:], VOL[t- settings['lookback'] +1:t+1,:], exposure[t- settings['lookback'] +2:t+2,:], equity[t- settings['lookback'] +1:t+1,:], settings);
            else:
-               position, settings = TSobject(DATE[t- settings['lookback'] +1:t+1], OPEN[t- settings['lookback'] +1:t+1,:], HIGH[t- settings['lookback'] +1:t+1,:], LOW[t- settings['lookback'] +1:t+1,:], CLOSE[t- settings['lookback']+1:t+1,:], VOL[t- settings['lookback'] +1:t+1,:], exposure[t- settings['lookback'] +2:t+2,:], equity[t- settings['lookback'] +1:t+1,:], settings);
+               position, settings = TSobject.myTradingSystem(DATE[t- settings['lookback'] +1:t+1], OPEN[t- settings['lookback'] +1:t+1,:], HIGH[t- settings['lookback'] +1:t+1,:], LOW[t- settings['lookback'] +1:t+1,:], CLOSE[t- settings['lookback']+1:t+1,:], VOL[t- settings['lookback'] +1:t+1,:], exposure[t- settings['lookback'] +2:t+2,:], equity[t- settings['lookback'] +1:t+1,:], settings);
         except:
             errorlog.append(str(DATE[t])+ ': ' + str(sys.exc_info()[0]))
             equity[t:,:] = np.tile(equity[t,:] - SLIPPAGE[t,:] * np.abs(todaysP) ,(nDays-t,1))
